@@ -5,12 +5,13 @@ use warnings;
 
 use lib './lib';
 use Net::Proxmox::VE;
+use IO::Socket::SSL qw(SSL_VERIFY_NONE);
 use Data::Dumper;
 use Getopt::Long;
 
 my $host     = 'host';
-my $username = 'root';
-my $password = 'password';
+my $username = 'user';
+my $password = 'pass';
 my $debug    = undef;
 my $realm    = 'pve'; # 'pve' or 'pam'
 
@@ -19,7 +20,7 @@ GetOptions (
     'username=s' => \$username,
     'password=s' => \$password,
     'debug'      => \$debug,
-    'realm'      => \$realm,
+    'realm=s'    => \$realm,
 );
 
 my $pve = Net::Proxmox::VE->new(
@@ -28,10 +29,14 @@ my $pve = Net::Proxmox::VE->new(
     password => $password,
     debug    => $debug,
     realm    => $realm,
+    ssl_opts => {
+        SSL_verify_mode => SSL_VERIFY_NONE,
+        verify_hostname => 0
+    },
 );
 
-die "login failed\n"         unless $pve->login;
-die "invalid login ticket\n" unless $pve->check_login_ticket;
+die "login failed\n"          unless $pve->login;
+die "invalid login ticket\n"  unless $pve->check_login_ticket;
 die "unsupport api version\n" unless $pve->api_version_check;
 
 # list nodes in cluster
@@ -44,6 +49,8 @@ print $pve->get('/access/users')
     ? "INFO: List Users Successful\n"
     : "WARNING: List Users Failed\n";
 
+__END__
+
 # Create a test user
 print $pve->put('/access/users',{'userid' => 'testuser@foobar'})
     ? "INFO: Create User Successful\n"
